#!/bin/bash
 
# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# last revised : 21/06/2011
#
#package			: sakura
#homepage			: http://www.pleyades.net/david/sakura.php
#source location                : "http://launchpad.net/sakura/trunk/2.4.2/+download/sakura-2.4.2.tar.bz2" "http://zenwalk.pinguix.com/user-accounts/stillborn/sakura/sakura.png"
#dependency: 
#you need cmake

set -u -x -e

#> log
(

softname='sakura'
softversion='2.4.2'
zenver='72.1'
arch='i486'
cpu='i686'
#numjobs='-j2'

#>

buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$zenver"
dest="$buildir/$package"
source="http://launchpad.net/sakura/trunk/2.4.2/+download/sakura-2.4.2.tar.bz2"
sourcetemplate="http://zenwalk.pinguix.com/user-accounts/stillborn/sakura"

#>

INS644="install -o root -g root -m 644"
INS755="install -d -o root -g root -m 755"

#>
rm -rfv $dest
rm -fv $package.{txz,src,dep,md5}
$INS755 $dest/{install,usr/{man,doc/$softname-$softversion,share/icons/hicolor/{48x48,scalable}/apps,src/$softname-$softversion}}

#> prepare slack-desc
cat <<EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
sakura: $softname - is a terminal emulator based on GTK and VTE.
sakura:
sakura: It's a terminal emulator with few dependencies, so you don't need
sakura: a full GNOME desktop installed to have a decent terminal emulator.
sakura: 
sakura: 
sakura: 
sakura:
sakura:
sakura:
sakura:
EOF

#> check for sources
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

if [ -f $softname.png ]; then
        echo "Icon file already here, no need to download";
else
        echo "Downloading icon"
        wget -c http://zenwalk.pinguix.com/user-accounts/stillborn/$softname/$softname.png
fi

#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar xjvf $srcpkg
cd $src	

sed -i '/^\(.*Ubuntu.*\)$/g' $softname.desktop
sed -i 's%Icon=\(.*\)$%Icon=sakura%' $softname.desktop
sed -i 's%Comment=\(.*\)$%Comment=terminal emulator%' $softname.desktop
sed -i 's%-O2%-O2 -march=i486 -mtune=i686%' CMakeLists.txt

cmake -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_VERBOSE_MAKEFILE=TRUE .
make 
make install DESTDIR=$dest

#> prepare icon
$INS644 $src/terminal-tango.svg $dest/usr/share/icons/hicolor/scalable/apps/$softname.svg
$INS644 $buildir/$softname.png $dest/usr/share/icons/hicolor/48x48/apps


#> add docs, infos, ...
(cd $src
$INS644 \
      AUTHORS GPL INSTALL \
$dest/usr/doc/$softname-$softversion
rm -rfv $dest/usr/share/doc
)


#> Strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

mv $dest/usr/share/man/man1 $dest/usr/man
( rm -rfv $dest/usr/share/man
  cd $dest/usr/man
  find . -type f -name "*.?" -exec gzip -9 {} \;
  for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

#> store buildscript 
(
cd $buildir
$INS644 build-$softname.sh $dest/usr/src/$softname-$softversion
)

#> fix permissions
(
chown -R root.root $dest
cd $dest
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(
cd $dest
makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
depfinder $package.txz > $package.dep
echo $sourcetemplate/build-$softname.sh > $package.src
echo $source >> $package.src
echo $sourcetemplate/$softname.png >> $package.src

#>
rm -rf $src
rm -rf $dest


#> log
) 2>&1 | tee sakura-build.log.txt
